@@ -15,9 +15,11 @@ from gi.repository import GLib, GObject, Gio
 import os
 from gettext import gettext as _
 from threading import Thread
+from time import time
 
 from lollypop.inotify import Inotify
 from lollypop.define import Lp
+from lollypop.sqlcursor import SqlCursor
 from lollypop.tagreader import ScannerTagReader
 from lollypop.utils import is_audio, is_pls, debug
 
@@ -42,7 +44,7 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
 
         self._thread = None
         self._inotify = None
-        if Lp.settings.get_value('auto-update'):
+        if Lp().settings.get_value('auto-update'):
             self._inotify = Inotify()
         self._progress = None
 
@@ -57,12 +59,12 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
             # Keep track of on file with missing codecs
             self._missing_codecs = None
             self.init_discover()
-            paths = Lp.settings.get_music_paths()
+            paths = Lp().settings.get_music_paths()
             if not paths:
                 return
 
-            if Lp.notify is not None:
-                Lp.notify.send(_("Your music is updating"))
+            if Lp().notify is not None:
+                Lp().notify.send(_("Your music is updating"))
             self._thread = Thread(target=self._scan, args=(paths,))
             self._thread.daemon = True
             self._thread.start()
@@ -129,11 +131,13 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
         """
             Notify from main thread when scan finished
         """
+        Lp().settings.set_value('db-mtime', GLib.Variant('i', int(time())))
         self.stop()
         self.emit("scan-finished")
         if self._missing_codecs is not None:
-            Lp.player.load_external(GLib.filename_to_uri(self._missing_codecs))
-            Lp.player.play_first_external()
+            Lp().player.load_external(
+                                    GLib.filename_to_uri(self._missing_codecs))
+            Lp().player.play_first_external()
 
     def _scan(self, paths):
         """
@@ -142,9 +146,8 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
             @thread safe
         """
         self._new_albums = []
-        sql = Lp.db.get_cursor()
-        mtimes = Lp.tracks.get_mtimes(sql)
-        orig_tracks = Lp.tracks.get_paths(sql)
+        mtimes = Lp().tracks.get_mtimes()
+        orig_tracks = Lp().tracks.get_paths()
         is_empty = len(orig_tracks) == 0
 
         # Add monitors on dirs
@@ -153,67 +156,65 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
             for d in new_dirs:
                 self._inotify.add_monitor(d)
 
-        i = 0
-        for filepath in new_tracks:
-            if self._thread is None:
-                sql.close()
-                return
-            GLib.idle_add(self._update_progress, i, count)
-            try:
-                mtime = int(os.path.getmtime(filepath))
-                if filepath not in orig_tracks:
-                    try:
-                        debug("Adding file: %s" % filepath)
-                        infos = self.get_infos(filepath)
-                        self._add2db(filepath, mtime, infos, sql)
-                    except Exception as e:
-                        debug("Error scanning: %s, %s" % (filepath, e))
-                        string = "%s" % e
-                        if string.startswith('gst-core-error-quark'):
-                            self._missing_codecs = filepath
-                else:
-                    # Update tags by removing song and readd it
-                    if mtime != mtimes[filepath]:
-                        debug("Adding file: %s" % filepath)
-                        infos = self.get_infos(filepath)
-                        if infos is not None:
-                            self._add2db(filepath, mtime, infos, sql)
-                        else:
-                            print("Can't get infos for ", filepath)
+        with SqlCursor(Lp().db) as sql:
+            i = 0
+            for filepath in new_tracks:
+                if self._thread is None:
+                    return
+                GLib.idle_add(self._update_progress, i, count)
+                try:
+                    mtime = int(os.path.getmtime(filepath))
+                    if filepath not in orig_tracks:
+                        try:
+                            debug("Adding file: %s" % filepath)
+                            infos = self.get_infos(filepath)
+                            self._add2db(filepath, mtime, infos)
+                        except Exception as e:
+                            debug("Error scanning: %s, %s" % (filepath, e))
+                            string = "%s" % e
+                            if string.startswith('gst-core-error-quark'):
+                                self._missing_codecs = filepath
                     else:
-                        orig_tracks.remove(filepath)
+                        # Update tags by removing song and readd it
+                        if mtime != mtimes[filepath]:
+                            debug("Adding file: %s" % filepath)
+                            infos = self.get_infos(filepath)
+                            if infos is not None:
+                                self._add2db(filepath, mtime, infos)
+                            else:
+                                print("Can't get infos for ", filepath)
+                        else:
+                            orig_tracks.remove(filepath)
 
-            except Exception as e:
-                print(ascii(filepath))
-                print("CollectionScanner::_scan(): %s" % e)
-            i += 1
+                except Exception as e:
+                    print(ascii(filepath))
+                    print("CollectionScanner::_scan(): %s" % e)
+                i += 1
 
-        # Restore stats for new albums
-        if not is_empty:
-            for album_id in self._new_albums:
-                duration = Lp.albums.get_duration(album_id, None, sql)
-                count = Lp.albums.get_count(album_id, None, sql)
-                value = Lp.albums.get_stats(duration, count)
-                if value is not None:
-                    Lp.albums.set_popularity(album_id, value[0], True, sql)
-                    Lp.albums.set_mtime(album_id, value[1], sql)
+            # Restore stats for new albums
+            if not is_empty:
+                for album_id in self._new_albums:
+                    duration = Lp().albums.get_duration(album_id, None)
+                    count = Lp().albums.get_count(album_id, None)
+                    value = Lp().albums.get_stats(duration, count)
+                    if value is not None:
+                        Lp().albums.set_popularity(album_id, value[0])
+                        Lp().albums.set_mtime(album_id, value[1])
 
-        # Clean deleted files
-        for filepath in orig_tracks:
-            track_id = Lp.tracks.get_id_by_path(filepath, sql)
-            self._del_from_db(track_id, sql)
+            # Clean deleted files
+            for filepath in orig_tracks:
+                track_id = Lp().tracks.get_id_by_path(filepath)
+                self._del_from_db(track_id)
 
-        sql.commit()
-        sql.close()
+            sql.commit()
         GLib.idle_add(self._finish)
 
-    def _add2db(self, filepath, mtime, infos, sql):
+    def _add2db(self, filepath, mtime, infos):
         """
             Add new file to db with informations
             @param filepath as string
             @param file modification time as int
             @param infos as GstPbutils.DiscovererInfo
-            @param sql as sqlite cursor
             @return track id as int
         """
         tags = infos.get_tags()
@@ -229,11 +230,9 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
         duration = int(infos.get_duration()/1000000000)
 
         (artist_ids, new_artist_ids) = self.add_artists(artists,
-                                                        album_artist,
-                                                        sql)
+                                                        album_artist)
 
-        (album_artist_id, new) = self.add_album_artist(album_artist,
-                                                       sql)
+        (album_artist_id, new) = self.add_album_artist(album_artist)
         if new:
             new_artist_ids.append(album_artist_id)
 
@@ -244,14 +243,14 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
 
         (album_id, new) = self.add_album(album_name, album_artist_id,
                                          no_album_artist, year, filepath, 0,
-                                         mtime, sql)
+                                         mtime)
         if new:
             self._new_albums.append(album_id)
 
-        (genre_ids, new_genre_ids) = self.add_genres(genres, album_id, sql)
+        (genre_ids, new_genre_ids) = self.add_genres(genres, album_id)
 
         # Restore stats
-        value = Lp.tracks.get_stats(filepath, duration, sql)
+        value = Lp().tracks.get_stats(filepath, duration)
         if value is None:
             popularity = 0
             ltime = 0
@@ -259,36 +258,36 @@ class CollectionScanner(GObject.GObject, ScannerTagReader):
             popularity = value[0]
             ltime = value[1]
         # Add track to db
-        track_id = Lp.tracks.add(title, filepath, duration,
-                                 tracknumber, discnumber,
-                                 album_id, year, popularity, ltime, mtime, sql)
-        self.update_track(track_id, artist_ids, genre_ids, sql)
+        track_id = Lp().tracks.add(title, filepath, duration,
+                                   tracknumber, discnumber,
+                                   album_id, year, popularity, ltime, mtime)
+        self.update_track(track_id, artist_ids, genre_ids)
 
         # Notify about new artists/genres
         if new_genre_ids or new_artist_ids:
-            sql.commit()
+            with SqlCursor(Lp().db) as sql:
+                sql.commit()
             for genre_id in new_genre_ids:
                 GLib.idle_add(self.emit, 'genre-update', genre_id)
             for artist_id in new_artist_ids:
                 GLib.idle_add(self.emit, 'artist-update', artist_id, album_id)
         return track_id
 
-    def _del_from_db(self, track_id, sql):
+    def _del_from_db(self, track_id):
         """
             Delete track from db
             @param track_id as int
-            @param sql as sqlite cursor
         """
-        album_id = Lp.tracks.get_album_id(track_id, sql)
-        genre_ids = Lp.tracks.get_genre_ids(track_id, sql)
-        album_artist_id = Lp.albums.get_artist_id(album_id, sql)
-        artist_ids = Lp.tracks.get_artist_ids(track_id, sql)
-        Lp.tracks.remove(track_id, sql)
-        Lp.tracks.clean(track_id, sql)
-        modified = Lp.albums.clean(album_id, sql)
+        album_id = Lp().tracks.get_album_id(track_id)
+        genre_ids = Lp().tracks.get_genre_ids(track_id)
+        album_artist_id = Lp().albums.get_artist_id(album_id)
+        artist_ids = Lp().tracks.get_artist_ids(track_id)
+        Lp().tracks.remove(track_id)
+        Lp().tracks.clean(track_id)
+        modified = Lp().albums.clean(album_id)
         if modified:
             GLib.idle_add(self.emit, 'album-modified', album_id)
         for artist_id in [album_artist_id] + artist_ids:
-            Lp.artists.clean(artist_id, sql)
+            Lp().artists.clean(artist_id)
         for genre_id in genre_ids:
-            Lp.genres.clean(genre_id, sql)
+            Lp().genres.clean(genre_id)
