@@ -18,7 +18,6 @@ from datetime import datetime
 
 from lollypop.define import Lp, ArtSize, Type
 from lollypop.utils import seconds_to_string
-from lollypop.pop_slider import SliderPopover
 from lollypop.pop_next import NextPopover
 
 
@@ -62,9 +61,6 @@ class FullScreen(Gtk.Window):
         self._datetime = builder.get_object('datetime')
 
         self._progress = builder.get_object('progress_scale')
-        self._slider_popover = SliderPopover()
-        self._slider_popover.set_relative_to(self._progress)
-        self._slider_popover.set_position(Gtk.PositionType.BOTTOM)
         self._timelabel = builder.get_object('playback')
         self._total_time_label = builder.get_object('duration')
         self.connect('key-release-event', self._on_key_release_event)
@@ -74,16 +70,16 @@ class FullScreen(Gtk.Window):
         """
             Init signals, set color and go party mode if nothing is playing
         """
-        is_playing = Lp.player.is_playing()
-        self._signal1_id = Lp.player.connect('current-changed',
-                                             self._on_current_changed)
-        self._signal2_id = Lp.player.connect('status-changed',
-                                             self._on_status_changed)
+        is_playing = Lp().player.is_playing()
+        self._signal1_id = Lp().player.connect('current-changed',
+                                               self._on_current_changed)
+        self._signal2_id = Lp().player.connect('status-changed',
+                                               self._on_status_changed)
         if is_playing:
             self._change_play_btn_status(self._pause_image, _('Pause'))
-            self._on_current_changed(Lp.player)
+            self._on_current_changed(Lp().player)
         else:
-            Lp.player.set_party(True)
+            Lp().player.set_party(True)
         if self._timeout1 is None:
             self._timeout1 = GLib.timeout_add(1000, self._update_position)
         Gtk.Window.do_show(self)
@@ -98,7 +94,7 @@ class FullScreen(Gtk.Window):
         self._update_position()
         self.fullscreen()
         self._next_popover.set_relative_to(self._album)
-        if Lp.player.next_track.id != Type.RADIOS:
+        if Lp().player.next_track.id != Type.RADIOS:
             self._next_popover.show()
 
     def do_hide(self):
@@ -107,10 +103,10 @@ class FullScreen(Gtk.Window):
         """
         Gtk.Window.do_hide(self)
         if self._signal1_id is not None:
-            Lp.player.disconnect(self._signal1_id)
+            Lp().player.disconnect(self._signal1_id)
             self._signal1_id = None
         if self._signal2_id is not None:
-            Lp.player.disconnect(self._signal2_id)
+            Lp().player.disconnect(self._signal2_id)
             self._signal2_id = None
         if self._timeout1 is not None:
             GLib.source_remove(self._timeout1)
@@ -163,38 +159,6 @@ class FullScreen(Gtk.Window):
         """
         self.destroy()
 
-    def _on_progress_motion_notify(self, eventbox, event):
-        """
-            Show progress popover
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
-        """
-        slider_width = self._progress.style_get_property('slider-width') / 2
-        rect = self._progress.get_range_rect()
-        if event.x < slider_width or\
-           event.x > rect.width - slider_width:
-            return
-
-        current = (event.x - slider_width) *\
-            self._progress.get_adjustment().get_upper() /\
-            (rect.width - slider_width * 2)
-        self._slider_popover.set(seconds_to_string(current/60))
-        r = Gdk.Rectangle()
-        r.x = event.x
-        r.y = rect.height
-        r.width = 1
-        r.height = 1
-        self._slider_popover.set_pointing_to(r)
-        self._slider_popover.show()
-
-    def _on_progress_leave_notify(self, eventbox, event):
-        """
-            Show progress popover
-            @param eventbox as Gtk.EventBox
-            @param event as Gdk.Event
-        """
-        self._slider_popover.delayed_hide()
-
     def _on_current_changed(self, player):
         """
             Update View for current track
@@ -205,18 +169,18 @@ class FullScreen(Gtk.Window):
             @param player as Player
         """
         if player.current_track.id is not None:
-            if Lp.player.current_track.id == Type.RADIOS:
+            if Lp().player.current_track.id == Type.RADIOS:
                 self._timelabel.hide()
                 self._total_time_label.hide()
                 self._progress.hide()
-                surface = Lp.art.get_radio_artwork(
+                surface = Lp().art.get_radio_artwork(
                     player.current_track.artist,
                     ArtSize.MONSTER*self.get_scale_factor())
             else:
                 self._timelabel.show()
                 self._total_time_label.show()
                 self._progress.show()
-                surface = Lp.art.get_album_artwork(
+                surface = Lp().art.get_album_artwork(
                     player.current_track.album,
                     ArtSize.MONSTER*self.get_scale_factor())
             self._cover.set_from_surface(surface)
@@ -228,7 +192,7 @@ class FullScreen(Gtk.Window):
             self._title.set_text(player.current_track.title)
             self._artist.set_text(player.current_track.artist)
             self._album.set_text(album_name)
-            self._progress.set_value(1.0)
+            self._progress.set_value(0.0)
             self._progress.set_range(0.0, player.current_track.duration * 60)
             self._total_time_label.set_text(
                 seconds_to_string(player.current_track.duration))
@@ -269,18 +233,18 @@ class FullScreen(Gtk.Window):
             Go to prev track
             @param widget as Gtk.Button
         """
-        Lp.player.prev()
+        Lp().player.prev()
 
     def _on_play_btn_clicked(self, widget):
         """
             Play/pause
             @param widget as Gtk.Button
         """
-        if Lp.player.is_playing():
-            Lp.player.pause()
+        if Lp().player.is_playing():
+            Lp().player.pause()
             widget.set_image(self._play_image)
         else:
-            Lp.player.play()
+            Lp().player.play()
             widget.set_image(self._pause_image)
 
     def _on_next_btn_clicked(self, widget):
@@ -288,15 +252,15 @@ class FullScreen(Gtk.Window):
             Go to next track
             @param widget as Gtk.Button
         """
-        Lp.player.next()
+        Lp().player.next()
 
     def _on_status_changed(self, obj):
         """
             Update buttons and progress bar
             @param obj as unused
         """
-        is_playing = Lp.player.is_playing()
-        if Lp.player.current_track.id != Type.RADIOS:
+        is_playing = Lp().player.is_playing()
+        if Lp().player.current_track.id != Type.RADIOS:
             self._progress.set_sensitive(is_playing)
         if is_playing and not self._timeout1:
             self._timeout1 = GLib.timeout_add(1000, self._update_position)
