@@ -12,7 +12,7 @@
 
 import random
 
-from lollypop.define import Shuffle
+from lollypop.define import Shuffle, Lp
 from lollypop.player_base import BasePlayer
 from lollypop.objects import Track
 
@@ -28,11 +28,23 @@ class UserPlaylistPlayer(BasePlayer):
         """
         BasePlayer.__init__(self)
         self._user_playlist_id = None
+        self._user_playlist = []
+        self._user_playlist_backup = []
+
+    def load_in_playlist(self, track_id):
+        """
+            Load track from playlist
+            @param track id as int
+        """
+        for track in self._user_playlist:
+            if track.id == track_id:
+                self.load(track)
+                break
 
     def set_user_playlist_id(self, playlist_id):
         """
-            Set playlist id
-            @param id as int
+            Set user playlist id
+            @param playlist id as int
         """
         self._user_playlist_id = playlist_id
 
@@ -43,19 +55,38 @@ class UserPlaylistPlayer(BasePlayer):
         """
         return self._user_playlist_id
 
-    def set_user_playlist(self, tracks, track_id):
+    def set_user_playlist_by_id(self, playlist_id):
+        """
+            Set user playlist as current playback playlist
+            @param array of tracks as [Track]
+            @return track id as Track
+            @thread safe
+        """
+        tracks = []
+        self._user_playlist_id = playlist_id
+        for track_id in Lp().playlists.get_tracks_ids(playlist_id):
+            if track_id == Lp().player.current_track.id:
+                tracks.append(Lp().player.current_track)
+            else:
+                tracks.append(Track(track_id))
+        self._user_playlist = tracks
+        self._shuffle_playlist()
+
+    def set_user_playlist_by_tracks(self, tracks):
         """
             Set user playlist as current playback playlist
             @param array of tracks as [Track]
             @param track id as int
-            @return track id as Track
         """
-        self._user_playlist = tracks
-        self._shuffle_playlist()
+        if Lp().player.is_party():
+            Lp().player.set_party(False)
+        self._user_playlist = []
         for track in tracks:
-            if track.id == track_id:
-                return track
-        return None
+            if track.id == Lp().player.current_track.id:
+                self._user_playlist.append(Lp().player.current_track)
+            else:
+                self._user_playlist.append(track)
+        self._shuffle_playlist()
 
     def get_user_playlist(self):
         """
@@ -108,13 +139,13 @@ class UserPlaylistPlayer(BasePlayer):
         """
         if self._shuffle == Shuffle.TRACKS:
             # Shuffle user playlist
-            if self._user_playlist is not None:
+            if self._user_playlist:
                 self._user_playlist_backup = list(self._user_playlist)
                 random.shuffle(self._user_playlist)
         # Unshuffle
         else:
-            if self._user_playlist_backup is not None:
+            if self._user_playlist_backup:
                 self._user_playlist = self._user_playlist_backup
-                self._user_playlist_backup = None
+                self._user_playlist_backup = []
         self.set_next()
         self.set_prev()
