@@ -87,7 +87,8 @@ class SearchRow(Gtk.ListBoxRow):
             Prepend track to queue
             @param button as Gtk.Button
         """
-        Lp.window.show_playlist_manager(self.id, None, not self.is_track)
+        Lp().window.show_playlist_manager(self.id, None, not self.is_track)
+        self._parent.hide()
 
     def _on_queue_clicked(self, button):
         """
@@ -95,10 +96,10 @@ class SearchRow(Gtk.ListBoxRow):
             @param button as Gtk.Button
         """
         if self.is_track:
-            Lp.player.append_to_queue(self.id)
+            Lp().player.append_to_queue(self.id)
         else:
-            for track in Lp.albums.get_tracks(self.id, None):
-                Lp.player.append_to_queue(track)
+            for track in Lp().albums.get_tracks(self.id, None):
+                Lp().player.append_to_queue(track)
         button.hide()
 
     def _on_query_tooltip(self, widget, x, y, keyboard, tooltip):
@@ -166,7 +167,7 @@ class SearchPopover(Gtk.Popover):
         builder.get_object('scrolled').add(self._view)
         self.add(builder.get_object('widget'))
 
-        size_setting = Lp.settings.get_value('window-size')
+        size_setting = Lp().settings.get_value('window-size')
         if isinstance(size_setting[1], int):
             self.set_size_request(400, size_setting[1]*0.7)
         else:
@@ -205,46 +206,44 @@ class SearchPopover(Gtk.Popover):
             Populate treeview searching items
             in db based on text entry current text
         """
-        sql = Lp.db.get_cursor()
         results = []
         albums = []
 
         tracks_non_album_artist = []
 
         # Get all albums for all artists and non album_artist tracks
-        for artist_id in Lp.artists.search(self._current_search, sql):
-            for album_id in Lp.albums.get_ids(artist_id, None, sql):
+        for artist_id in Lp().artists.search(self._current_search):
+            for album_id in Lp().albums.get_ids(artist_id, None):
                 if (album_id, artist_id) not in albums:
                     albums.append((album_id, artist_id))
-            for track_id, track_name in Lp.tracks.get_as_non_album_artist(
-                                                        artist_id, sql):
+            for track_id, track_name in Lp().tracks.get_as_non_album_artist(
+                                                        artist_id):
                 tracks_non_album_artist.append((track_id, track_name))
 
-        albums += Lp.albums.search(self._current_search, sql)
+        albums += Lp().albums.search(self._current_search)
 
         for album_id, artist_id in albums:
             search_obj = SearchObject()
-            search_obj.artist = Lp.artists.get_name(artist_id, sql)
-            search_obj.title = Lp.albums.get_name(album_id, sql)
-            search_obj.count = Lp.albums.get_count(album_id, None, sql)
+            search_obj.artist = Lp().artists.get_name(artist_id)
+            search_obj.title = Lp().albums.get_name(album_id)
+            search_obj.count = Lp().albums.get_count(album_id, None)
             search_obj.id = album_id
             search_obj.album_id = album_id
             results.append(search_obj)
 
-        for track_id, track_name in Lp.tracks.search(
-                        self._current_search, sql) + tracks_non_album_artist:
+        for track_id, track_name in Lp().tracks.search(
+                        self._current_search) + tracks_non_album_artist:
             search_obj = SearchObject()
             search_obj.title = track_name
             search_obj.id = track_id
-            search_obj.album_id = Lp.tracks.get_album_id(track_id, sql)
+            search_obj.album_id = Lp().tracks.get_album_id(track_id)
             search_obj.is_track = True
 
-            artist_id = Lp.albums.get_artist_id(search_obj.album_id,
-                                                sql)
+            artist_id = Lp().albums.get_artist_id(search_obj.album_id)
             if artist_id == Type.COMPILATIONS:
-                search_obj.artist = Lp.tracks.get_artist_names(track_id, sql)
+                search_obj.artist = Lp().tracks.get_artist_names(track_id)
             else:
-                search_obj.artist = Lp.artists.get_name(artist_id, sql)
+                search_obj.artist = Lp().artists.get_name(artist_id)
 
             results.append(search_obj)
 
@@ -255,8 +254,6 @@ class SearchPopover(Gtk.Popover):
             self._in_thread = False
             self._stop_thread = False
 
-        sql.close()
-
     def _add_rows(self, results):
         """
             Add a rows recursively
@@ -270,7 +267,7 @@ class SearchPopover(Gtk.Popover):
                     result.title += " (%s)" % result.count
                 search_row.set_text(result.artist, result.title)
                 search_row.set_cover(
-                        Lp.art.get_album_artwork(
+                        Lp().art.get_album_artwork(
                                      Album(result.album_id),
                                      ArtSize.MEDIUM*self.get_scale_factor()))
                 search_row.id = result.id
@@ -285,15 +282,15 @@ class SearchPopover(Gtk.Popover):
             self._in_thread = False
             self._stop_thread = False
 
-    def _set_user_playlist(self, tracks, track_id):
+    def _set_user_playlist_by_tracks(self, tracks, track_id):
         """
             Set user playlist
             @param tracks as [Track]
             @param track id as int
             @thread safe
         """
-        track = Lp.player.set_user_playlist(tracks, track_id)
-        Lp.player.load(track)
+        Lp().player.load(Track(track_id))
+        Lp().player.set_user_playlist_by_tracks(tracks)
 
     def _play_search(self, object_id=None, is_track=True):
         """
@@ -301,62 +298,55 @@ class SearchPopover(Gtk.Popover):
             @param started object id as int
             @param is track as bool
         """
-        sql = Lp.db.get_cursor()
         tracks = []
         track_id = None
         for child in self._view.get_children():
             if child.is_track:
                 tracks.append(Track(child.id))
             else:
-                album_tracks = Lp.albums.get_tracks(child.id, None, sql)
+                album_tracks = Lp().albums.get_tracks(child.id, None)
                 if not is_track and child.id == object_id and album_tracks:
                     track_id = album_tracks[0]
                 for tid in album_tracks:
                     tracks.append(Track(tid))
         if tracks:
-            GLib.idle_add(Lp.player.set_party, False)
             if object_id is not None and is_track:
                 track_id = object_id
             elif track_id is None:
                 track_id = tracks[0].id
             GLib.idle_add(self._set_user_playlist, tracks, track_id)
-        sql.close()
 
     def _new_playlist(self):
         """
             Create a new playlist based on search
         """
-        sql = Lp.db.get_cursor()
         tracks = []
         for child in self._view.get_children():
             if child.is_track:
                 tracks.append(Track(child.id))
             else:
-                for track_id in Lp.albums.get_tracks(child.id, None, sql):
+                for track_id in Lp().albums.get_tracks(child.id, None):
                     tracks.append(Track(child.id))
-        sql.close()
 
         if tracks:
-            sql = Lp.playlists.get_cursor()
-            playlist_id = Lp.playlists.get_id(self._current_search, sql)
+            playlist_id = Lp().playlists.get_id(self._current_search)
             if playlist_id == Type.NONE:
-                Lp.playlists.add(self._current_search, sql)
-            Lp.playlists.add_tracks(playlist_id, tracks, sql)
-            sql.close()
+                Lp().playlists.add(self._current_search)
+            Lp().playlists.add_tracks(playlist_id, tracks)
 
     def _on_map(self, widget):
         """
             Disable global shortcuts
             @param widget as Gtk.Widget
         """
-        Lp.window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shorcuts(False)
 
     def _on_unmap(self, widget):
         """
             Enable global shortcuts
             @param widget as Gtk.Widget
         """
-        Lp.window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shorcuts(True)
 
     def _on_search_changed(self, widget):
         """
@@ -400,7 +390,6 @@ class SearchPopover(Gtk.Popover):
             @param widget as Gtk.ListBox
             @param row as SearchRow
         """
-        Lp.player.set_party(False)
         t = Thread(target=self._play_search, args=(row.id, row.is_track))
         t.daemon = True
         t.start()
