@@ -308,6 +308,8 @@ class SelectionList(Gtk.ScrolledWindow):
             icon = 'emblem-favorite-symbolic'
         elif object_id == Type.NEVER:
             icon = 'document-new-symbolic'
+        elif object_id == Type.MPD:
+            icon = 'network-workgroup-symbolic'
         return icon
 
     def _sort_items(self, model, itera, iterb, data):
@@ -359,7 +361,7 @@ class SelectionList(Gtk.ScrolledWindow):
             @param widget as Gtk.widget
             @param event as GdK.Event
         """
-        Lp.window.enable_global_shorcuts(False)
+        Lp().window.enable_global_shorcuts(False)
 
     def _on_focus_out_event(self, widget, event):
         """
@@ -367,7 +369,7 @@ class SelectionList(Gtk.ScrolledWindow):
             @param widget as Gtk.widget
             @param event as GdK.Event
         """
-        Lp.window.enable_global_shorcuts(True)
+        Lp().window.enable_global_shorcuts(True)
 
     def _on_leave_event(self, widget=None, event=None):
         """
