@@ -10,12 +10,13 @@
 # You should have received a copy of the GNU General Public License
 # along with this program. If not, see <http://www.gnu.org/licenses/>.
 
-from gi.repository import Gtk, GLib
+from gi.repository import Gtk, GLib, Gdk
 
 from lollypop.view import View
 from lollypop.view_container import ViewContainer
 from lollypop.widgets_album import AlbumSimpleWidget
 from lollypop.widgets_album_context import AlbumContextWidget
+from lollypop.widgets_album_context import AlbumPopoverWidget
 from lollypop.define import Lp, ArtSize
 from lollypop.objects import Album, Track
 
@@ -67,10 +68,12 @@ class AlbumsView(View):
         self._is_compilation = is_compilation
         self._albumsongs = None
         self._context_widget = None
+        self._press_rect = None
 
         self._albumbox = Gtk.FlowBox()
         self._albumbox.set_selection_mode(Gtk.SelectionMode.NONE)
         self._albumbox.connect('child-activated', self._on_album_activated)
+        self._albumbox.connect('button-press-event', self._on_button_press)
         self._albumbox.set_property('column-spacing', 5)
         self._albumbox.set_property('row-spacing', 5)
         self._albumbox.set_homogeneous(True)
@@ -90,10 +93,10 @@ class AlbumsView(View):
         self._paned = Gtk.Paned.new(Gtk.Orientation.VERTICAL)
         self._paned.pack1(self._scrolledWindow, True, False)
         self._paned.pack2(self._context, False, False)
-        height = Lp.settings.get_value('paned-context-height').get_int32()
+        height = Lp().settings.get_value('paned-context-height').get_int32()
         # We set a stupid max value, safe as self._context is shrinked
         if height == -1:
-            height = Lp.window.get_allocated_height()
+            height = Lp().window.get_allocated_height()
         self._paned.set_position(height)
         self._paned.connect('notify::position', self._on_position_notify)
         self._paned.show()
@@ -160,28 +163,57 @@ class AlbumsView(View):
             @param paned as Gtk.Paned
             @param param as Gtk.Param
         """
-        Lp.settings.set_value('paned-context-height',
-                              GLib.Variant('i', paned.get_position()))
+        Lp().settings.set_value('paned-context-height',
+                                GLib.Variant('i', paned.get_position()))
         return False
 
     def _on_album_activated(self, flowbox, child):
         """
             Show Context view for activated album
             @param flowbox as Gtk.Flowbox
-            @child as Gtk.FlowboxChild
+            @param child as Gtk.FlowboxChild
         """
-        if self._context_album_id == child.get_child().get_id():
-            self._context_album_id = None
-            self._context.hide()
-            self._context_widget.destroy()
-            self._context_widget = None
+        album_widget = child.get_child()
+        if self._press_rect is None:
+            if self._context_album_id == album_widget.get_id():
+                self._context_album_id = None
+                self._context.hide()
+                self._context_widget.destroy()
+                self._context_widget = None
+            else:
+                if Lp().settings.get_value('auto-play'):
+                    album = Album(album_widget.get_id())
+                    track = Track(album.tracks_ids[0])
+                    Lp().player.load(track)
+                    Lp().player.set_albums(track.id, None,
+                                           self._genre_id)
+                else:
+                    self._context_album_id = album_widget.get_id()
+                    self._populate_context(self._context_album_id)
+                    self._context.show()
         else:
-            self._context_album_id = child.get_child().get_id()
-            if Lp.settings.get_value('auto-play'):
-                album = Album(self._context_album_id)
-                track = Track(album.tracks_ids[0])
-                Lp.player.load(track)
-                Lp.player.set_albums(track.id, None,
-                                     self._genre_id)
-            self._populate_context(self._context_album_id)
-            self._context.show()
+            if self._context_album_id is not None:
+                self._context_album_id = None
+                self._context.hide()
+                self._context_widget.destroy()
+                self._context_widget = None
+            popover = AlbumPopoverWidget(album_widget.get_id(),
+                                         self._genre_id)
+            popover.set_relative_to(album_widget)
+            popover.set_pointing_to(self._press_rect)
+            popover.show()
+
+    def _on_button_press(self, flowbox, event):
+        """
+            Store pressed button
+            @param flowbox as Gtk.Flowbox
+            @param event as Gdk.EventButton
+        """
+        if event.button == 1:
+            self._press_rect = None
+        else:
+            self._press_rect = Gdk.Rectangle()
+            self._press_rect.x = event.x
+            self._press_rect.y = event.y
+            self._press_rect.width = self._press_rect.height = 1
+            event.button = 1
