@@ -146,12 +146,10 @@ class CurrentArtistAlbumsView(ViewContainer):
             Get albums
             @return album ids as [int]
         """
-        sql = Lp.db.get_cursor()
         if artist_id == Type.COMPILATIONS:
-            albums = [Lp.player.current_track.album_id]
+            albums = [Lp().player.current_track.album_id]
         else:
-            albums = Lp.artists.get_albums(artist_id, sql)
-        sql.close()
+            albums = Lp().artists.get_albums(artist_id)
         return albums
 
     def do_get_preferred_width(self):
